@@ -6,6 +6,7 @@
 #include <QNetworkAccessManager>
 #include <QTime>
 #include <QFile>
+#include <QDBusVariant>
 
 namespace Ui
 {
@@ -15,6 +16,7 @@ class RCQTextEdit;
 class UsbManager;
 class QTextEdit;
 class HelpWindow;
+class DeviceDiscoveryDialog;
 
 class MainWindow : public QMainWindow
 {
@@ -32,10 +34,12 @@ private:
     QTime downloadTime;
     QFile downfile;
     UsbManager *m_usbmanage;
+    DeviceDiscoveryDialog *m_btdevice;
     QTextEdit *m_helpwindow;
     QStringList hfiles;
     QColor bgtextcolor;
     QColor textcolor;
+    QString btclientadr;
 
 protected:
     void closeEvent(QCloseEvent *event);
@@ -55,7 +59,7 @@ private slots:
     void on_listWidget_real_doubleClicked(QModelIndex index);
     int runtime_filter(QString);
     void refresh_filter();
-    void on_pushButton_showresolv_clicked();
+    void showresolv();
     void on_pushButton_adddns_clicked();
     void on_pushButton_routedefaultadd_clicked();
     void on_pushButton_gweadd_clicked();
@@ -112,6 +116,7 @@ private slots:
     QString getBTcon();
     QString getBTproperty(QString key);
     QString getBTdevPath();
+    QString getBTadapterPath(QString address);
     QString getlsof();
     QString write_filter(QString);
     QString filterlog(QString linelog);
@@ -217,11 +222,24 @@ private slots:
     void on_pushButton_viewfontcolor_clicked();
     void textcolorset(QColor);
     void bgtextcolorset(QColor);
+    void dhcp_client();
 
     void on_pushButton_clients_clicked();
 
+    void on_comboBox_resolv_currentIndexChanged(const QString &arg1);
+
+    void on_pushButton_btsearch_clicked();
+
+    void on_pushButton_dhclient_clicked();
+    void checkConnection(QString name, QDBusVariant value);
+
 public slots:
     void helpaktion_button(bool act, bool forground);
+    void bt_connect(QString btaddress, QString btservice);
+    void bt_trust(QString btaddress);
+
+signals:
+    void refresh_trust(QString btaddress);
 
 };
 
